@@ -17,24 +17,25 @@ build_time_vars = {'ABIFLAGS': '',
               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'armv6--netbsdelf-eabihf',
+ 'BUILD_GNU_TYPE': 'armv7--netbsdelf-eabihf',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -D_FORTIFY_SOURCE=2 '
-           '-I/usr/include -I/usr/pkg/include -O2 -D_FORTIFY_SOURCE=2 '
-           '-I/usr/include -I/usr/pkg/include -O2 -D_FORTIFY_SOURCE=2 '
-           '-I/usr/include -I/usr/pkg/include',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -fPIC '
+           '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 -fPIC '
+           '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 -fPIC '
+           '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
+ 'CONFIGURE_CFLAGS': '-O2 -fPIC -D_FORTIFY_SOURCE=2 -I/usr/include '
                      '-I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
+                            '-Wno-cast-function-type '
                             '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
  'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
@@ -43,22 +44,23 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-ffi' "
                 "'--without-ensurepip' '--without-pymalloc' "
-                "'--prefix=/usr/pkg' '--build=armv6--netbsdelf-eabihf' "
-                "'--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
+                "'--prefix=/usr/pkg' '--build=armv7--netbsdelf-eabihf' "
+                "'--host=armv7--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
                 "'--enable-option-checking=yes' "
-                "'build_alias=armv6--netbsdelf-eabihf' "
-                "'host_alias=armv6--netbsdelf-eabihf' 'CC=gcc' 'CFLAGS=-O2 "
-                "-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include' "
+                "'build_alias=armv7--netbsdelf-eabihf' "
+                "'host_alias=armv7--netbsdelf-eabihf' 'CC=gcc' 'CFLAGS=-O2 "
+                "-fPIC -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include' "
                 "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
                 "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
                 "'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' "
-                "'PKG_CONFIG=' 'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/.buildlink/lib/pkgconfig:/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/.buildlink/share/pkgconfig'",
+                "'PKG_CONFIG=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/.tools/bin/pkg-config' "
+                "'PKG_CONFIG_PATH=' "
+                "'PKG_CONFIG_LIBDIR=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/.buildlink/lib/pkgconfig:/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.7',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.5/coverage.info',
- 'COVERAGE_REPORT': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.5/lcov-report',
+ 'COVERAGE_INFO': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.15/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.15/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
@@ -173,6 +175,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 1,
+ 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 0,
@@ -217,7 +220,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
- 'HAVE_GETENTROPY': 0,
+ 'HAVE_GETENTROPY': 1,
  'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 0,
@@ -236,7 +239,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
- 'HAVE_GETRANDOM': 0,
+ 'HAVE_GETRANDOM': 1,
  'HAVE_GETRANDOM_SYSCALL': 0,
  'HAVE_GETRESGID': 0,
  'HAVE_GETRESUID': 0,
@@ -441,7 +444,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
- 'HAVE_SYS_RANDOM_H': 0,
+ 'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 0,
@@ -503,7 +506,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'armv6--netbsdelf-eabihf',
+ 'HOST_GNU_TYPE': 'armv7--netbsdelf-eabihf',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.7 /usr/pkg/include/python3.7',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -591,7 +594,8 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '-I/usr/include',
  'OPENSSL_LDFLAGS': '-L/usr/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -fPIC -D_FORTIFY_SOURCE=2 -I/usr/include '
+        '-I/usr/pkg/include',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -625,31 +629,34 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                             '-D_FORTIFY_SOURCE=2 -I/usr/include '
-                             '-I/usr/pkg/include -O2 -D_FORTIFY_SOURCE=2 '
-                             '-I/usr/include -I/usr/pkg/include -O2 '
+                             '-fPIC -D_FORTIFY_SOURCE=2 -I/usr/include '
+                             '-I/usr/pkg/include -O2 -fPIC -D_FORTIFY_SOURCE=2 '
+                             '-I/usr/include -I/usr/pkg/include -O2 -fPIC '
                              '-D_FORTIFY_SOURCE=2 -I/usr/include '
                              '-I/usr/pkg/include -std=gnu99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
+                             '-Wno-cast-function-type '
                              '-Werror=implicit-function-declaration -I. '
                              '-I./Include -I/usr/include -I/usr/pkg/include '
                              '-I/usr/include -I/usr/pkg/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 '
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -fPIC '
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 -fPIC '
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 -fPIC '
               '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wno-cast-function-type '
                      '-Werror=implicit-function-declaration',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -fPIC '
                    '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                   '-std=gnu99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-fPIC -D_FORTIFY_SOURCE=2 -I/usr/include '
+                   '-I/usr/pkg/include -O2 -fPIC -D_FORTIFY_SOURCE=2 '
+                   '-I/usr/include -I/usr/pkg/include -std=gnu99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wno-cast-function-type '
                    '-Werror=implicit-function-declaration -I. -I./Include '
                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
                    '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
@@ -667,13 +674,14 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -fPIC '
                         '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                        '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-                        '-I/usr/pkg/include -O2 -D_FORTIFY_SOURCE=2 '
+                        '-O2 -fPIC -D_FORTIFY_SOURCE=2 -I/usr/include '
+                        '-I/usr/pkg/include -O2 -fPIC -D_FORTIFY_SOURCE=2 '
                         '-I/usr/include -I/usr/pkg/include -std=gnu99 -Wextra '
                         '-Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
+                        '-Wno-cast-function-type '
                         '-Werror=implicit-function-declaration -I. -I./Include '
                         '-I/usr/include -I/usr/pkg/include -I/usr/include '
                         '-I/usr/pkg/include -fPIC',
@@ -684,7 +692,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.5',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.15',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
@@ -726,10 +734,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.5 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.15 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.5 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.15 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -741,6 +749,7 @@ build_time_vars = {'ABIFLAGS': '',
  'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.7',
  'WINDOW_HAS_FLAGS': 0,
+ 'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
@@ -750,8 +759,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.5',
- 'abs_srcdir': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.5',
+ 'abs_builddir': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.15',
+ 'abs_srcdir': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.15',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
