@@ -1,24 +1,18 @@
-#!/usr/bin/env python2
-from __future__ import print_function
-
 import os
 import os.path
 import pkgutil
-import shutil
 import sys
+import runpy
 import tempfile
 
 
 __all__ = ["version", "bootstrap"]
-
-
-_SETUPTOOLS_VERSION = "40.6.2"
-
-_PIP_VERSION = "18.1"
-
+_PACKAGE_NAMES = ('setuptools', 'pip')
+_SETUPTOOLS_VERSION = "47.1.0"
+_PIP_VERSION = "22.0.4"
 _PROJECTS = [
-    ("setuptools", _SETUPTOOLS_VERSION),
-    ("pip", _PIP_VERSION),
+    ("setuptools", _SETUPTOOLS_VERSION, "py3"),
+    ("pip", _PIP_VERSION, "py3"),
 ]
 
 
@@ -27,9 +21,18 @@ def _run_pip(args, additional_paths=None):
     if additional_paths is not None:
         sys.path = additional_paths + sys.path
 
-    # Install the bundled software
-    import pip._internal
-    return pip._internal.main(args)
+    # Invoke pip as if it's the main module, and catch the exit.
+    backup_argv = sys.argv[:]
+    sys.argv[1:] = args
+    try:
+        # run_module() alters sys.modules and sys.argv, but restores them at exit
+        runpy.run_module("pip", run_name="__main__", alter_sys=True)
+    except SystemExit as exc:
+        return exc.code
+    finally:
+        sys.argv[:] = backup_argv
+
+    raise SystemError("pip did not exit, this should never happen")
 
 
 def version():
@@ -38,7 +41,6 @@ def version():
     """
     return _PIP_VERSION
 
-
 def _disable_pip_configuration_settings():
     # We deliberately ignore all pip environment variables
     # when invoking pip
@@ -51,8 +53,8 @@ def _disable_pip_configuration_settings():
     os.environ['PIP_CONFIG_FILE'] = os.devnull
 
 
-def bootstrap(root=None, upgrade=False, user=False,
-              altinstall=False, default_pip=True,
+def bootstrap(*, root=None, upgrade=False, user=False,
+              altinstall=False, default_pip=False,
               verbosity=0):
     """
     Bootstrap pip into the current Python installation (or the given root
@@ -66,9 +68,9 @@ def bootstrap(root=None, upgrade=False, user=False,
                verbosity=verbosity)
 
 
-def _bootstrap(root=None, upgrade=False, user=False,
-               altinstall=False, default_pip=True,
-               verbosity=0):
+def _bootstrap(*, root=None, upgrade=False, user=False,
+              altinstall=False, default_pip=False,
+              verbosity=0):
     """
     Bootstrap pip into the current Python installation (or the given root
     directory). Returns pip command status code.
@@ -93,13 +95,12 @@ def _bootstrap(root=None, upgrade=False, user=False,
         # omit pip and easy_install
         os.environ["ENSUREPIP_OPTIONS"] = "install"
 
-    tmpdir = tempfile.mkdtemp()
-    try:
+    with tempfile.TemporaryDirectory() as tmpdir:
         # Put our bundled wheels into a temporary directory and construct the
         # additional paths that need added to sys.path
         additional_paths = []
-        for project, version in _PROJECTS:
-            wheel_name = "{}-{}-py2.py3-none-any.whl".format(project, version)
+        for project, version, py_tag in _PROJECTS:
+            wheel_name = "{}-{}-{}-none-any.whl".format(project, version, py_tag)
             whl = pkgutil.get_data(
                 "ensurepip",
                 "_bundled/{}".format(wheel_name),
@@ -110,7 +111,7 @@ def _bootstrap(root=None, upgrade=False, user=False,
             additional_paths.append(os.path.join(tmpdir, wheel_name))
 
         # Construct the arguments to be passed to the pip command
-        args = ["install", "--no-index", "--find-links", tmpdir]
+        args = ["install", "--no-cache-dir", "--no-index", "--find-links", tmpdir]
         if root:
             args += ["--root", root]
         if upgrade:
@@ -121,10 +122,8 @@ def _bootstrap(root=None, upgrade=False, user=False,
             args += ["-" + "v" * verbosity]
 
         return _run_pip(args + [p[0] for p in _PROJECTS], additional_paths)
-    finally:
-        shutil.rmtree(tmpdir, ignore_errors=True)
 
-def _uninstall_helper(verbosity=0):
+def _uninstall_helper(*, verbosity=0):
     """Helper to support a clean default uninstall process on Windows
 
     Note that calling this function may alter os.environ.
@@ -196,16 +195,9 @@ def _main(argv=None):
     parser.add_argument(
         "--default-pip",
         action="store_true",
-        default=True,
-        dest="default_pip",
-        help=argparse.SUPPRESS,
-    )
-    parser.add_argument(
-        "--no-default-pip",
-        action="store_false",
-        dest="default_pip",
-        help=("Make a non default install, installing only the X and X.Y "
-              "versioned scripts."),
+        default=False,
+        help=("Make a default pip install, installing the unqualified pip "
+              "and easy_install in addition to the versioned scripts."),
     )
 
     args = parser.parse_args(argv)
